using System;

namespace CreditProcessLib.Validators
{
	/// <summary>
	/// Validator for credit card numbers. Current version
	/// limited to checking only Visa and Mastercard and
	/// does not perform the check digit.
	/// </summary>
	public class CardNumberValidator : ICardNumberValidator
	{
		#region ICardNumberValidator Members

		/// <summary>
		/// Checks if the card number if valid. 
		/// </summary>
		/// <param name="cardNumber">Card number to be validated</param>
		/// <returns>true if card number if valid, false otherwise.</returns>
		public bool IsValid(string cardNumber)
		{
			bool result = true;

			switch(cardNumber[0])
			{
				case '4': // Visa
					if (cardNumber.Length != 13 && cardNumber.Length != 16)
					{
						result = false;
					}
					break;
				case '5': // Mastercard
					if (cardNumber.Length != 16)
					{
						result = false;
					}
					if (Convert.ToInt32(cardNumber[1].ToString()) > 5)
					{
						result = false;
					}
					break;
				default:
					result = false;
					break;
			}

			return result;
		}

		#endregion
	}
}
